"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = getAuthorizationUrl;

var _client = _interopRequireDefault(require("../oauth/client"));

var _logger = _interopRequireDefault(require("../../../lib/logger"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

async function getAuthorizationUrl(req) {
  var _provider$version;

  const {
    provider
  } = req.options;
  const client = (0, _client.default)(provider);

  if ((_provider$version = provider.version) !== null && _provider$version !== void 0 && _provider$version.startsWith('2.')) {
    var _req$query;

    (_req$query = req.query) === null || _req$query === void 0 ? true : delete _req$query.nextauth;
    let url = client.getAuthorizeUrl({ ...provider.authorizationParams,
      ...req.query,
      redirect_uri: provider.callbackUrl,
      scope: provider.scope
    });

    if (provider.authorizationUrl.includes('?')) {
      const parseUrl = new URL(provider.authorizationUrl);
      const baseUrl = `${parseUrl.origin}${parseUrl.pathname}?`;
      url = url.replace(baseUrl, provider.authorizationUrl + '&');
    }

    _logger.default.debug('GET_AUTHORIZATION_URL', url);

    return url;
  }

  try {
    const oAuthToken = await client.getOAuthRequestToken();
    const url = `${provider.authorizationUrl}?oauth_token=${oAuthToken}`;

    _logger.default.debug('GET_AUTHORIZATION_URL', url);

    return url;
  } catch (error) {
    _logger.default.error('GET_AUTHORIZATION_URL_ERROR', error);

    throw error;
  }
}